@@ -8,6 +8,7 @@ var exec = require("child_process").execFile
   , fs = require("graceful-fs")
   , chain = require("slide").chain
   , log = require("npmlog")
+  , which = require("which")
   , npm = require("./npm.js")
 
 version.usage = "npm version [<newversion> | major | minor | patch | build]\n"
@@ -76,27 +77,39 @@ function checkGit (data, cb) {
   var args = [ "status", "--porcelain" ]
   var env = process.env
 
-  exec(git, args, {env: env}, function (er, stdout, stderr) {
-    var lines = stdout.trim().split("\n").filter(function (line) {
-      return line.trim() && !line.match(/^\?\? /)
-    }).map(function (line) {
-      return line.trim()
-    })
-    if (lines.length) return cb(new Error(
-      "Git working directory not clean.\n"+lines.join("\n")))
-    write(data, function (er) {
-      if (er) return cb(er)
-      var message = npm.config.get("message").replace(/%s/g, data.version)
-        , sign = npm.config.get("sign-git-tag")
-        , flag = sign ? "-sm" : "-am"
-      chain
-        ( [ [ exec, git, [ "add", "package.json" ], {env: process.env} ]
-          , [ exec, git, [ "commit", "-m", message ], {env: process.env} ]
-          , [ exec, git, [ "tag", "v" + data.version, flag, message ]
-            , {env: process.env} ] ]
-        , cb )
-    })
+  // check for git
+  which(git, function (err) {
+    if (err) {
+      err.code = "ENOGIT"
+      return cb(err)
+    }
+
+    gitFound()
   })
+
+  function gitFound () {
+    exec(git, args, {env: env}, function (er, stdout, stderr) {
+      var lines = stdout.trim().split("\n").filter(function (line) {
+        return line.trim() && !line.match(/^\?\? /)
+      }).map(function (line) {
+        return line.trim()
+      })
+      if (lines.length) return cb(new Error(
+        "Git working directory not clean.\n"+lines.join("\n")))
+      write(data, function (er) {
+        if (er) return cb(er)
+        var message = npm.config.get("message").replace(/%s/g, data.version)
+          , sign = npm.config.get("sign-git-tag")
+          , flag = sign ? "-sm" : "-am"
+        chain
+          ( [ [ exec, git, [ "add", "package.json" ], {env: process.env} ]
+            , [ exec, git, [ "commit", "-m", message ], {env: process.env} ]
+            , [ exec, git, [ "tag", "v" + data.version, flag, message ]
+              , {env: process.env} ] ]
+          , cb )
+      })
+    })
+  }
 }
 
 function write (data, cb) {
